aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--xbmc/cores/dvdplayer/DVDCodecs/Video/DVDVideoCodecAndroidMediaCodec.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/xbmc/cores/dvdplayer/DVDCodecs/Video/DVDVideoCodecAndroidMediaCodec.cpp b/xbmc/cores/dvdplayer/DVDCodecs/Video/DVDVideoCodecAndroidMediaCodec.cpp
index 589683f967..2eaea8d97f 100644
--- a/xbmc/cores/dvdplayer/DVDCodecs/Video/DVDVideoCodecAndroidMediaCodec.cpp
+++ b/xbmc/cores/dvdplayer/DVDCodecs/Video/DVDVideoCodecAndroidMediaCodec.cpp
@@ -275,8 +275,8 @@ void CDVDMediaCodecInfo::UpdateTexImage()
// wait, then video playback gets jerky. To optomize this,
// we hook the SurfaceTexture OnFrameAvailable callback
// using CJNISurfaceTextureOnFrameAvailableListener and wait
- // on a CEvent to fire. 20ms seems to be a good max fallback.
- m_frameready->WaitMSec(20);
+ // on a CEvent to fire. 50ms seems to be a good max fallback.
+ m_frameready->WaitMSec(50);
m_surfacetexture->updateTexImage();
if (xbmc_jnienv()->ExceptionOccurred())